<?php
/**
 * Testimonial options.
 *
 * @package Kuza
 */

$default = kuza_get_default_theme_options();

// Testimonial Section
$wp_customize->add_section( 'section_home_testimonial',
	array(
		'title'      => __( 'Testimonial Section', 'kuza' ),
		'capability' => 'edit_theme_options',
		'panel'      => 'home_page_panel',
		'active_callback' => 'kuza_testimonial_design_enable',
		)
);

$wp_customize->add_setting( 'theme_options[disable_testimonial_section]',
	array(
		'default'           => $default['disable_testimonial_section'],
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'kuza_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Kuza_Switch_Control( $wp_customize, 'theme_options[disable_testimonial_section]',
    array(
		'label' 			=> __('Enable/Disable Testimonial Section', 'kuza'),
		'section'    		=> 'section_home_testimonial',
		 'settings'  		=> 'theme_options[disable_testimonial_section]',
		'on_off_label' 		=> kuza_switch_options(),
    )
) );

// Testimonial Image
$wp_customize->add_setting('theme_options[testimonial_side_image]', 
	array(
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'kuza_sanitize_image'
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
	'theme_options[testimonial_side_image]', 
	array(
	'label'       => __('Section Side Image', 'kuza'),
	'section'     => 'section_home_testimonial',   
	'settings'    => 'theme_options[testimonial_side_image]',		
	'active_callback' => 'kuza_testimonial_active',
	'type'        => 'image',
	)
	)
);

// Add dots enable setting and control.
$wp_customize->add_setting( 'theme_options[testimonial_dots_enable]', array(
	'default'           => $default['testimonial_dots_enable'],
	'sanitize_callback' => 'kuza_sanitize_checkbox',
) );

$wp_customize->add_control( 'theme_options[testimonial_dots_enable]', array(
	'label'             => esc_html__( 'Enable Post Slider Slider Dots', 'kuza' ),
	'section'           => 'section_home_testimonial',
	'type'              => 'checkbox',
	'active_callback' => 'kuza_testimonial_active',
) );


//About Section title
$wp_customize->add_setting('theme_options[testimonial_title]', 
	array(
	'default'           => $default['testimonial_title'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[testimonial_title]', 
	array(
	'label'       => __('Section Title', 'kuza'),
	'section'     => 'section_home_testimonial',   
	'settings'    => 'theme_options[testimonial_title]',
	'active_callback' => 'kuza_testimonial_active',		
	'type'        => 'text'
	)
);

//About Section Subtitle
$wp_customize->add_setting('theme_options[testimonial_subtitle]', 
	array(
	'default'           => $default['testimonial_subtitle'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_textarea_field'
	)
);

$wp_customize->add_control('theme_options[testimonial_subtitle]', 
	array(
	'label'       => __('Section Sub Title', 'kuza'),
	'section'     => 'section_home_testimonial',   
	'settings'    => 'theme_options[testimonial_subtitle]',
	'active_callback' => 'kuza_testimonial_active',		
	'type'        => 'textarea'
	)
);

$number_of_testimonial_items = kuza_get_option( 'number_of_testimonial_items' );

for( $i=1; $i<=$number_of_testimonial_items; $i++ ){

	// Additional Information First Page
	$wp_customize->add_setting('theme_options[testimonial_page_'.$i.']', 
		array(
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',	
		'sanitize_callback' => 'kuza_dropdown_pages'
		)
	);

	$wp_customize->add_control('theme_options[testimonial_page_'.$i.']', 
		array(
		'label'       => sprintf( __('Select Page #%1$s', 'kuza'), $i),
		'section'     => 'section_home_testimonial',   
		'settings'    => 'theme_options[testimonial_page_'.$i.']',		
		'type'        => 'dropdown-pages',
		'active_callback' => 'kuza_testimonial_active',
		)
	);

}